/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2010. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, 
 * duplication or disclosure restricted by GSA ADP Schedule 
 * Contract with IBM Corp.
 *******************************************************************************/
package net.jazz.rtcext.workitem.extensions.ide.ui;

import net.jazz.rtcext.workitem.extensions.common.IBuildOnStateChangeDefinitions;

import org.eclipse.osgi.util.NLS;

import com.ibm.team.process.ide.ui.IProcessAspectEditorFactory;
import com.ibm.team.process.ide.ui.ProcessAspectEditor;

/**
 * This factory class is configured in the aspect editor extension point, not
 * the aspect editor class itself. One factory may be configured to construct
 * several aspect editors. The process framework passes in the id of the aspect
 * so that the factory knows which to create.
 */
public class AspectEditorFactory implements IProcessAspectEditorFactory {

	/**
	 * This is the factory method called by the process framework to get the
	 * aspect editor.
	 * 
	 * @param processAspectId
	 *            the aspect id as configured in the extension point. One
	 *            factory may be configured to construct several different
	 *            aspect editors.
	 * @return the aspect editor
	 */
	public ProcessAspectEditor createProcessAspectEditor(String processAspectId) {
		/*
		 * If the aspect id is recognized, return the proper aspect editor.
		 */
		if (processAspectId.equals(IBuildOnStateChangeDefinitions.EXTENSION_ID)) {
			return new BuildOnStateChangeAspectEditor();
		}

		/*
		 * It should never happen that an unrecognized id is passed to this
		 * method, however, it is common practice to handle that case by
		 * throwing an illegal argument exception.
		 */
		throw new IllegalArgumentException(NLS.bind("Unknown aspect id: {0}",
				processAspectId));
	}

}
